bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 22. Aventiure
___________________________________________________
| ### <Si> was ce Zeizenmvre vnz an den vierden tach ### div molte vff der straze di wile ni gelach ### sine stvebe alsam ez brvenne allenthalben dan ### da ritten dvrch Osteriche des chvnich Eceln man ### Do was ovch dem chvenige vil rehte nv geseit ### des im von den gedanchen swnden siniv leit ### wi herlichen Criemhilt da chome dvrch div lant ### der kvenich begonde gahen da er di wolgetanen vant [356b]
###### 1335 | ### Von vil maniger sprache sah man vffe den wegen ### vor Eceln riten manigen chvenen degen ### von cristen vnd von heiden vil manige wite schar ### da si di vrowen fvnden si chomen herliche dar
| ### Von Rivzen vnd von Criechen reit da vil manich man ### den Poelan vnt den Walachen sach man swinde gan ### ir ross div vil gvten da si mit creffte riten ### swaz si site heten der wart vil wenich vermiten
###### 1337 | ### Uon dem lande ze Chiewen reit da vil manich degen ### vnt di wilden Petsschenære da wart vil gepflegen ### mit dem bogen schiezen cen vogeln di da flvgen ### di pfile si vil sere zv den wenden vaste zvgen
###### 1338 | ### Ein stat bi Tvonowe lit in Osterlant ### div ist geheizen Tvln da wart ir bechant ### vil manich site vremede den si ê nie gesach ### si enpfiengen da genvge den sit leit von ir gesach
| ### Vor Eceln dem chvenege ein ingesinde reit ### vro vnd vil riche hoefsh vnt gemeit ### wol vier vnd zweinzech fversten tiwer vnd her ### daz si ir vrowen sæhen da von engerten si niht mer
###### 1340 | ### Der herzoge Ramvnch vzer Walachen lant ### mit siben hvndert mannen chom er fver si gerant ### sam vliegende vogele sah man si varn ### do chom der fverste Gybecke mit vil herlichen scharn
###### 1341 | ### Hornboge der snelle wol mit tvsent man ### cherte von dem chvenege gegen siner vrowen dan ### vil lvte wart geschallet nach des landes siten ### von der Hivnen magen wart ovch da sere geritten
| ### Do chom von Tenemarchen der chvene Hawart ### vnt Yrinch der vil snelle vor valsche wol bewart ### vnt Irnfrit von Dveringen ein wætlicher man ### si enpfiengen Criemhilde daz sis ere mvsen han
###### 1343 | ### mit zwelf hvndert mannen di fvrtens in ir schar ### do chom der herre Bloedelin mit drin tvsent dar ### der Eceln brvder vzer Hivnen lant ### der chom <vil> herliche da er di chveneginne vant
###### 1344 | ### Do chom der chvenich Ecel vnd ovch her Dietrich ### mit allen sinen gesellen da was vil lobelich ### manich ritter edele biderbe vnd gvt ### des wart do vrovn Criemhilde vil wol gehoehet der mvt
| ### Do sprach cer kveneginne der herre Rvedger ### vrowe ich wil enpfahen hie den chvnich her ### swen ich ivch heize chvessen daz sol sin getan [357a] ### iane mvgt ir niht geliche gervzen <alle> Eceln man
###### 1346 | ### Do hvp man von dem moere di chveneginne her ### Ecel der vil riche enbeite do niht mer ### er stvnt von sinem rosse mit manigem chvenem man ### man sah in vroliche gegen Criemhilde gan
###### 1347 | ### Zwene fvrsten riche als vns daz ist geseit ### bi der vrvn gende trvgn iriv chleit ### da ir der chvonich Ecel hin engegen gie ### da si den fvrsten edele mit chvsse gvetliche enpfie
| ### Vf rvchte si ir gebende ir varwe wolgetan ### div lvht ir zv dem golde da was vil manich man ### di iahen daz vrov Helche niht schoener chvnde sin ### da bi so stvnt vil nahen des kveniges brvder Bloedelin
###### 1349 | ### Den hiez si chvessen Rvedeger der margrave rich ### vnt den kvnech Gybechen da stvnt ovch Dieterich ### der recken chvste zwelve daz Eceln wip ### do enpfie si svs mit grvze vil maniges riteres lip
###### 1350 | ### Al di wile vnd Ecel bi Chriemhilde stvnt ### do taten do di tvmben als noch di livte <tvnt> ### vil manigen pvneiz richen sah man da geriten ### daz taten Cristen helde vnd ovch di heiden nach ir siten
| ### Wi rehte ritterliche di Dieteriches man ### di schefte liezen vliegen mit trvnzvnen dan ### hohe vber di schilde gvter ritter hant ### von den tivschen gesten wart dverchel manich schildes rant
###### 1352 | ### Da wart von schefte brechen vil michel doz vernomen ### do waren von dem lande di <rechen> alle chomen ### vnt ovch des chveneges geste vil manich edel man ### do gie der kvnech riche mit vrovn Criemhilde dan
###### 1353 | ### Si sahen bi in stende ein vil herlich gezelt ### von hvetten was erfvllet alvmbe daz velt ### da si <solden> rwen nach ir arbeit ### von helden wart gewiset dar vnder manich schoniv meit
###### 1354 | ### mit der chveneginne da si sit gesaz ### vf rich stvlgewæte der margrave daz ### hetez wol geschaffen daz man ez vant vil gvt ### daz gesidele Criemhilde des vroevt sich Eceln mvt
| ### Waz do redete Ecel daz ist mir vm [357b] bechant ### in der sinen zeswen lag ir wiziv hant ### si gesazen minnechliche da Rvedger der degen ### den kvenech niht wolde lazen Criemhilde heinliche pflegen
###### 1356 | ### Do hiez man lan beliben den bvhvrt veber al ### mit eren wart verendet da der groze schal ### do giengen zv den hveten di Eceln man ### man gap in herberge vil wite allenthalben dan
###### 1357 | ### Der tach der het nv ende si schvf ir gemach ### vnz man den liehten morgen aber schinen sach ### do was zv den rossen chomen manich man ### hey waz man chvrzewile dem chvenege ce eren began
| ### Der kvnech ez nach den eren di Hivnen schaffen bat ### do ritten si von Tvlne ce Wiene zv der stat ### da fvnden si gezieret vil maniger vrowen lip ### si enpfiengen wol mit eren des kvenech Eceln wip
###### 1359 | ### Mit harte grozen vollen so was in bereit ### swaz <si> haben solden vil manich helt gemeit ### sich vrevte gegen dem schalle herbergen man began ### des kvneges hohgezite div hvp sich vrolichen an
###### 1360 | ### Sine mohten niht geherbergen alle in der stat ### di niht geste waren Rvedger di bat ### daz si herberge næmen in daz lant ### ich wene man alle zite bi dem Criemhilde vant
###### 1361 | ### <· en> herren Dieterichen vnd andern manigen degen ### si heten sich der <rvwe> mit arbeit bewegen ### dvrch daz si den gesten trosten wol den mvt ### her Rvedger vnd sine vrivnde heten chvercewile gvt
###### 1362 | ### Div hohzit was gevallen an einen pfinxtach ### da der kvnech Ecel bi Criemhilde lach ### in der stat ce Wiene si wæn so manigen man ### bi ir ersten manne nie ze dienste gewan
###### 1363 | ### Si chvnte sich mit gabe dem der si nie gesach ### vil maniger dar vnder zv den gesten sprach ### wir wanden daz vrov Criemhilt gvtes niht mohte han ### nv ist hie mir ir gabe vil manich wnder getan
| ### Div hohzit div werte sibenzehen tage ### ich wæne man von deheinem kvnige mere sage ### des hohzit grozer wære daz ist vns gar verdeit ### alle di da waren di trvgen iteniwoe chleit
###### 1365 | ### Si wæn in Niderlande da vor nine gesaz [358a] ### mit so manigem recken da bi so gelovbe ich daz ### was Sifrit rich des gvtes daz er nie gewan ### so manigen recken edele so si sach vor Eceln stan
###### 1366 | ### Ovch gap nie deheiner zv sin selbes hohgezit ### so manigen richen mantel tief vnd wit ### noch so gvter cleider der si mohte vil han ### so si dvrch Criemhilde heten alle getan
| ### Ir frivnde vnt ovch di geste di heten einen mvt ### daz si da niht ensparten deheiner slahte gvt ### swes iemen an si gerte daz gaben si bereit ### des gestvnt da vil der degene von milte bloz ane chleit
###### 1368 | ### Wi si ce Rine sæze si gedaht ane daz ### bi ir edelen manne ir ovgen wrden naz ### si hetes vaste hæle deiz iemen chvnde sehen ### ir was nach manigem leide so vil der eren geschehen
###### 1369 | ### Swaz iemen tet mit milte daz was gar ein wint ### vnz an Dieterichen swaz Botelvnges chint ### im gegeben hete daz was nv gar verswant ### ovch begie da michel wnder des milten Rvedegeres hant
| ### Vzer Vngerlande der fverste Bloedelin ### der hiez da lære machen vil manich leitschrin ### von silber vnd von golde daz wart da hin gegeben ### man gesach des chveneges helde so rehte vroliche leben
###### 1371 | ### Wærbel vnd Swemmelin des kveniges spilman ### ich wæne ir ieselicher zer hohgezit gewan ### wol ce tvsent marchen oder dannoch baz ### da div schoene Criemhilt bi Ecel vnder chrone saz
###### 1372 | ### An dem ahzentem morgen von Wiene si do ritten ### da wart in ritterschepfte schilde vil versniten ### von spern di da fvrten di recken an der hant ### svs chom der chvenich Ecel vnz in daz hivnissche lant
| ### Ze Heimbvrch der alten si waren vber naht ### done chvnde niemen wizzen wol des volches aht ### mit wi getaner crefte si ritten veber lant ### hey waz man schoener vrowen in siner heinmvete vant
###### 1374 | ### Ze Misenbvrch der richen da shifften si sich an ### daz wazer wart verdechet von ross vnd ovch von man ### alsam ez [358b] erde wære swaz man sin vliezen sach ### di wegemveden vrowen di heten senfte vnd ovch gemach
###### 1375 | ### Zesamene was geslozen manich shif vil gvt ### dar veber was gespannen manich gvt gecelt ### sam ob si noch heten beidiv lant vnde velt
| ### Do chomen disiv mære ce Ecelnpvrch von dan ### do vrevten sich dar inne wip vnde man ### des Eceln ingesinde des ê div vrowe pflach ### gelebten sit bi Crimhilde vil manigen vroelichen tach
###### 1377 | ### Do stvnden da wartende vil manich edel meit ### di von Helchen tode heten manigiv leit ### siben chvenige toehter Crimhilt noch da vant ### von den was gezieret wol allez Eceln lant
###### 1378 | ### Div ivnchvrowe Herrat noch des gesindes pflach ### div Helchen swester tohter an der vil tvgende lach ### div gemahele Dieteriches eins edeln chvneges chint ### div tohter Næntwines div het vil der eren sint
| ### Gegen der geste chvemfte vrevte sich ir mvt ### ovch was dar zv bereitet vil creftigez gvt ### wer chvnde iv daz bescheiden wi sit der chvenech saz ### si gelebten da ce Hivnen nie mit der chvneginne baz
###### 1380 | ### Do der chvenech mit sinem wibe von dem stade reit ### wer ieslichiv wære daz wart do wol geseit ### di edelen Criemhilde si grvztens deste baz ### hey wi gewaltechliche si sit an Helchen stat gesaz
###### 1381 | ### Getriwelicher dienste wart ir vil bechant ### do teilte div chvneginne golt vnt gewant ### silber vnt gesteine swaz di des veber Rin ### mit ir cen Hivnen brahte daz mvse gar cergeben sin
| ### Ovch wrden ir mit dieneste sider vndertan ### alle des chveniges mage vnt alle sine man ### daz div vrowe Helche so gewalteclich gebot ### so si nv mvsen dienen vnz an den Criemhilde tot
###### 1383 | ### Do stvnt mit soelhen eren der hof vnt ovch daz lant ### daz man da zallen ziten di chvrzewile vant ### swar nach ieslichem daz herce trvch den mvt ### dvrh des chveneges liebe vnt di kveneginne gvt [359a]

<<< Übersicht <<< vorige Seite nächste Seite >>>